from tests import app


@app.route("/error-assert-query-invalid-regex")
def error_assert_query_invalid_regex():
    return ""
